@@ -29,7 +29,7 @@ import click
               help='Cache output of individual parameter point')
 @click.option('--save-log/--no-log', default=True, show_default=True,
               help='Save a log file for each parameter point.')
-@click.option('--save-summary/--no-summary', default=True, show_default=True,
+@click.option('--save-summary/--no-summary', default=True, show_default=False,
               help='Save a summary file for each parameter point.')
 @click.option('--parallel', type=int, default=-1, show_default=True,
               help='\b\n Parallelize job across the N workers.'
@@ -81,7 +81,7 @@ import click
               help='Minimizer algorithm')
 @click.option('-e', '--eps', type=float, default=1.0, show_default=True,
               help='Convergence criterium')
-@click.option('--retry', type=int, default=0, show_default=True,
+@click.option('--retry', type=int, default=2, show_default=True,
               help='Maximum number of retries upon a failed fit')
 @click.option('--strategy', type=int, default=1, show_default=True,
               help='Default minimization strategy')
