@@ -58,6 +58,10 @@ def build_xml_ws(**kwargs):
 @click.command(name='modify_ws')
 @click.option('-i', '--filename', 'source', required=True, 
               help='Input xml/json file.')
+@click.option('--input_workspace', 
+              help='Override input workspace path from the xml/json file.')
+@click.option('--output_workspace', 
+              help='Override output workspace path from the xml/json file.')
 @click.option('-t', '--minimizer_type', default="Minuit2", show_default=True,
               help='Minimizer type')
 @click.option('-a', '--minimizer_algo', default="Migrad", show_default=True,
@@ -90,13 +94,15 @@ def modify_ws(**kwargs):
     """
     Modify workspace from XML/json config files
     """
+    infile = kwargs.pop("input_workspace")
+    outfile = kwargs.pop("output_workspace")
     _kwargs = {}
     for arg_name in ["source", "verbosity"]:
         _kwargs[arg_name] = kwargs.pop(arg_name)
     _kwargs['minimizer_config'] = kwargs
     from quickstats.components.workspaces import XMLWSModifier
     modifier = XMLWSModifier(**_kwargs)
-    modifier.create_modified_workspace()
+    modifier.create_modified_workspace(infile=infile, outfile=outfile)
     
 kItemChoices = ['workspace', 'dataset', 'category', 'snapshot', 'pdf',
                 'function', 'poi', 'nuisance_parameter', 'global_observable',
@@ -161,6 +167,10 @@ def compare_ws(**kwargs):
 @click.command(name='combine_ws')
 @click.option('-i', '--filename', 'source', required=True, 
               help='Input xml file.')
+@click.option('--input_workspace', 
+              help='Override input workspace paths from the xml file. Format: <channel>=<path>,...')
+@click.option('--output_workspace', 
+              help='Override output workspace path from the xml file.')
 @click.option('--save_rename_ws/--skip_rename_ws', default=False, show_default=True,
               help='Save a temporary workspace after the rename step')
 @click.option('--save_combine_ws/--skip_combine_ws', default=False, show_default=True,
@@ -197,13 +207,27 @@ def combine_ws(**kwargs):
     """
     Combine workspace from XML config files
     """
+    infile = kwargs.pop("input_workspace")
+    outfile = kwargs.pop("output_workspace")
+    if infile is not None:
+        infiles = {}
+        for item in infile.split(","):
+            subitems = [i.strip() for i in item.split("=")]
+            if len(subitems) != 2:
+                raise ValueError("invalid format for the argument \"input_workspace\"")
+            infiles[subitems[0]] = subitems[1]
+    else:
+        infiles = None
+    save_rename_ws = kwargs.pop("save_rename_ws")
+    save_combine_ws = kwargs.pop("save_combine_ws")
     _kwargs = {}
-    _aux_kwargs = {}
     for arg_name in ["source", "verbosity"]:
         _kwargs[arg_name] = kwargs.pop(arg_name)
-    for arg_name in ["save_rename_ws", "save_combine_ws"]:
-        _aux_kwargs[arg_name] = kwargs.pop(arg_name)
     _kwargs['minimizer_config'] = kwargs
     from quickstats.components.workspaces import XMLWSCombiner
     combiner = XMLWSCombiner(**_kwargs)
-    combiner.run(**_aux_kwargs, save_final_ws=True)    
\ No newline at end of file
+    combiner.create_combined_workspace(infiles=infiles, outfile=outfile,
+                                       save_rename_ws=save_rename_ws,
+                                       save_combine_ws=save_combine_ws,
+                                       save_final_ws=True)    
+    
\ No newline at end of file
