@@ -132,6 +132,29 @@ class ExtendedMinimizer(AbstractObject):
     
     def set_data(self, data:"ROOT.RooAbsData"):
         self.data = data
+        
+    def _bug_fix_create_nll(self, dataset:"ROOT.RooDataSet", nll_commands:List["ROOT.RooCmdArg"]):
+        # fix range bug
+        use_named_range = any([i.GetName() == "RangeWithName" for i in nll_commands])
+        use_split_range = any([i.GetName() == "SplitRange" for i in nll_commands])
+        if (use_named_range and use_split_range) and isinstance(self.pdf, ROOT.RooSimultaneous):
+            named_range_cmd = [i for i in nll_commands if i.GetName() == "RangeWithName"][0]
+            named_ranges = named_range_cmd.getString(0).split(",")
+            index_cat = self.pdf.indexCat()
+            n_cat = index_cat.size()
+            for named_range in named_ranges:
+                for i in range(n_cat):
+                    index_cat.setIndex(i)
+                    cat_label = index_cat.getLabel()
+                    pdf_cat = self.pdf.getPdf(cat_label)
+                    observable = pdf_cat.getObservables(dataset).first()
+                    range_name = f"{named_range}_{cat_label}"
+                    if observable.hasRange(range_name):
+                        value_range = observable.getRange(range_name)
+                        observable.setRange(named_range, value_range[0], value_range[1])
+            index = [i for i, cmd in enumerate(nll_commands) if cmd.GetName() == "SplitRange"][0]
+            nll_commands.pop(index)
+            self.stdout.warning("WARNING: Renamed observable ranges to fix a bug in ROOT")
     
     def _create_nll(self, nll_commands:List["ROOT.RooCmdArg"]=None, 
                     dataset:Optional["ROOT.RooDataSet"]=None):
@@ -145,7 +168,8 @@ class ExtendedMinimizer(AbstractObject):
         if dataset is None:
             dataset = self.data
         
-        if quickstats.root_version >= (6, 26, 0):            
+        if quickstats.root_version >= (6, 26, 0):
+            self._bug_fix_create_nll(dataset, nll_commands)
             nll = self.pdf.createNLL(dataset, *nll_commands)
         else:
             if len(nll_commands) <= 6:
