@@ -221,6 +221,7 @@ class ExtendedModel(AbstractObject):
             raise RuntimeError(f'failed to load workspace "{self.ws_name}"')
         self.ws_name = ws.GetName()
         self.stdout.info(f'INFO: Loaded workspace "{self.ws_name}"')
+        
         # load model config
         if self.mc_name is None:
             mc_names = [i.GetName() for i in ws.allGenericObjects() if 'ModelConfig' in i.ClassName()]
@@ -266,8 +267,12 @@ class ExtendedModel(AbstractObject):
                 raise RuntimeError(f"no datasets found in the workspace: {ws_name}")
             self.data_name = data_names[0]
         data = ws.data(self.data_name)
+        # in case there is a bug in hash map
         if not data:
-            raise RuntimeError(f'failed to load dataset \"{self.data_name}\"')
+            data = [i for i in ws.allData() if i.GetName() == self.data_name]
+            if not data:
+                raise RuntimeError(f'failed to load dataset \"{self.data_name}\"')
+            data = data[0]
         self.stdout.info('INFO: Loaded dataset "{}" from workspace'.format(data.GetName()))
                 
         # load nuisance parameters
