@@ -85,7 +85,7 @@ class RooProcessor(AbstractObject):
             else:
                 all_files += glob.glob(fname)
         if not all_files:
-            raise FileNotFoundError(f"file `{filename}` does not exist")
+            raise FileNotFoundError(f'file "{filename}" does not exist')
         return all_files
     
     def run_action(self, action:RooProcBaseAction):
@@ -134,11 +134,11 @@ class RooProcessor(AbstractObject):
         self.sanity_check()
         all_files = self._get_all_files(filename)
         if len(all_files) == 1:
-            self.stdout.info(f"INFO: Processing file `{all_files[0]}`.")
+            self.stdout.info(f'INFO: Processing file "{all_files[0]}".')
         else:
             self.stdout.info(f"INFO: Professing files")
             for f in all_files:
-                self.stdout.info(f"\t`{f}`")  
+                self.stdout.info(f'\t"{f}"')  
         with Timer() as t:
             self.rdf = ROOT.RDataFrame(self.treename, all_files)
             self.action_tree.reset()
