@@ -1,8 +1,8 @@
+from typing import Optional, Union, List, Dict
 import os
 import re
 import json
 import time
-from typing import Optional, Union, List, Dict
 
 import numpy as np
 
@@ -11,13 +11,12 @@ from ROOT.RooPrintable import (kName, kClassName, kValue, kArgs, kExtras, kAddre
                                kTitle, kCollectionHeader, kSingleLine)
 
 import quickstats
-from quickstats import semistaticmethod, Timer
-from quickstats.components import AbstractObject, ExtendedModel
+from quickstats import semistaticmethod, Timer, AbstractObject, GeneralEnum
+from quickstats.components import ExtendedModel
 from quickstats.utils.io import Verbosity, get_colored_text, format_comparison_text
 from quickstats.utils.root_utils import load_macro, get_macro_dir
 from quickstats.maths.numerics import is_float, pretty_value
 from quickstats.components.basics import WSArgument
-from quickstats.utils.enums import GeneralEnum
 from quickstats.interface.root.roofit_extension import get_str_data
 
 kUnique        = 0b00001
