@@ -354,8 +354,9 @@ class XMLWSModifier(XMLWSBase):
                              f"{', '.join(extra_terms)}")
     
     def setup_parameters(self, ws:ROOT.RooWorkspace):
-        model = ExtendedModel(ws, data_name=None, verbosity="WARNING")
-        model.stdout.verbosity = "INFO"
+        data_name = self.config['data_name']
+        model = ExtendedModel(ws, data_name=data_name, verbosity="WARNING")
+        model.stdout.verbosity = self.stdout.verbosity
         if self.config["fix_parameters"] is not None:
             model.fix_parameters(self.config["fix_parameters"])
         if self.config["profile_parameters"] is not None:
