@@ -102,11 +102,11 @@ def str_decode_value(val_str):
 def is_nan_or_inf(value):
     return np.isnan(value) or np.isinf(value)
 
-def get_bins_given_edges(low_edge:float, high_edge:float, nbins:int):
+def get_bins_given_edges(low_edge:float, high_edge:float, nbins:int, decimals:int=8):
     bin_width = (high_edge - low_edge) / nbins
     low_bin_center  = low_edge + bin_width / 2
     high_bin_center = high_edge - bin_width /2
-    bins = np.linspace(low_bin_center, high_bin_center, nbins)
+    bins = np.around(np.linspace(low_bin_center, high_bin_center, nbins), decimals)
     return bins
 
 def array_issubset(a:np.ndarray, b:np.ndarray):
