@@ -105,8 +105,9 @@ class UpperLimit1DPlot(AbstractPlot):
             handles = (handle_fill, handle_line)
         self.update_legend_handles({'curve': handles})
 
-    def draw(self, logx: bool = False, xlabel: Optional[str] = None, markersize: float = 50.,
-             draw_observed: bool = True, draw_stat: bool = False, draw_third_column: Optional[str] = None, add_text: bool = True, sig_fig: int = 2):
+    def draw(self, logx:bool=False, xlabel:Optional[str]=None, markersize:float=50.,
+             draw_observed:bool=True, draw_stat:bool=False, draw_third_column:Optional[str]=None,
+             add_text:bool= True, sig_fig:int=2):
         if (draw_observed + draw_stat) > 1:
             raise RuntimeError(
                 "draw_observed and draw_stat can not be both True")
