@@ -21,9 +21,10 @@ def get_cpu_count():
 def parallel_run(func, *iterables, max_workers):
     from concurrent.futures  import ProcessPoolExecutor
     with ProcessPoolExecutor(max_workers) as executor:
-        result = executor.map(func, *iterables)
-
-    return [i for i in result]
+        results = []
+        for result in executor.map(func, *iterables):
+            results.append(result)
+    return results
 
 def execute_multi_tasks(func, *iterables, parallel):
     if parallel == 0:
